/*
  rdesktop: A Remote Desktop Protocol client.
  Amiga front-end etc
  Copyright (C) Martin Blom 2004-2005
            (C) Michal Zukowski 2013-2018
*/	

#include "show_disconnect_reason.h"
void show_disconnect_reason(uint16 reason)
{
	char *text;

	switch (reason)
	{
		case ERRINFO_NO_INFO:
			text = "No information available";
			break;

		case ERRINFO_RPC_INITIATED_DISCONNECT:
			text = "Server initiated disconnect";
			break;

		case ERRINFO_RPC_INITIATED_LOGOFF:
			text = "Server initiated logoff";
			break;

		case ERRINFO_IDLE_TIMEOUT:
			text = "Server idle timeout reached";
			break;

		case ERRINFO_LOGON_TIMEOUT:
			text = "Server logon timeout reached";
			break;

		case ERRINFO_DISCONNECTED_BY_OTHERCONNECTION:
			text = "The session was replaced";
			break;

		case ERRINFO_OUT_OF_MEMORY:
			text = "The server is out of memory";
			break;

		case ERRINFO_SERVER_DENIED_CONNECTION:
			text = "The server denied the connection";
			break;

		case ERRINFO_SERVER_DENIED_CONNECTION_FIPS:
			text = "The server denied the connection for security reason";
			break;

		case ERRINFO_SERVER_INSUFFICIENT_PRIVILEGES:
			text = "The user cannot connect to the server due to insufficient access privileges.";
		break;
		
		case ERRINFO_SERVER_FRESH_CREDENTIALS_REQUIRED:
			text = "The server does not accept saved user credentials and requires that the user enter their credentials for each connection.";
		break;
		
		case ERRINFO_RPC_INITIATED_DISCONNECT_BYUSER:
			text = "Disconnect initiated by user";
		break;
		
		case ERRINFO_LOGOFF_BYUSER:
			text = "Logout initiated by user";
		break;

		case ERRINFO_LICENSE_INTERNAL:
			text = "Internal licensing error";
			break;

		case ERRINFO_LICENSE_NO_LICENSE_SERVER:
			text = "No license server available";
			break;

		case ERRINFO_LICENSE_NO_LICENSE:
			text = "No valid license available";
			break;

		case ERRINFO_LICENSE_BAD_CLIENT_MSG:
			text = "Invalid licensing message";
			break;

		case ERRINFO_LICENSE_HWID_DOESNT_MATCH_LICENSE:
			text = "Hardware id doesn't match software license";
			break;

		case ERRINFO_LICENSE_BAD_CLIENT_LICENSE:
			text = "Client license error";
			break;

		case ERRINFO_LICENSE_CANT_FINISH_PROTOCOL:
			text = "Network error during licensing protocol";
			break;

		case ERRINFO_LICENSE_CLIENT_ENDED_PROTOCOL:
			text = "Licensing protocol was not completed";
			break;

		case ERRINFO_LICENSE_BAD_CLIENT_ENCRYPTION:
			text = "Incorrect client license enryption";
			break;

		case ERRINFO_LICENSE_CANT_UPGRADE_LICENSE:
			text = "Can't upgrade license";
			break;

		case ERRINFO_LICENSE_NO_REMOTE_CONNECTIONS:
			text = "The server is not licensed to accept remote connections";
			break;

		case ERRINFO_CB_DESTINATION_NOT_FOUND:
			text = "The target endpoint chosen by the broker could not be found";
		break;

		case ERRINFO_CB_LOADING_DESTINATION:
			text = "The target endpoint is disconnecting from the broker";
		break;

		case ERRINFO_CB_REDIRECTING_TO_DESTINATION:
			text = "Error occurred while being redirected by broker";
		break;

		case ERRINFO_CB_SESSION_ONLINE_VM_WAKE:
			text = "Error while the endpoint VM was being awakened by the broker";
		break;

		case ERRINFO_CB_SESSION_ONLINE_VM_BOOT:
			text = "Error while the endpoint VM was being started by the broker";
		break;

		case ERRINFO_CB_SESSION_ONLINE_VM_NO_DNS:
			text = "The IP address of the endpoint VM could not be determined by the broker";
		break;

		case ERRINFO_CB_DESTINATION_POOL_NOT_FREE:
			text = "No available endpoints in the connection broker pool";
		break;

		case ERRINFO_CB_CONNECTION_CANCELLED:
			text = "Connection processing cancelled by the broker";
		break;

		case ERRINFO_CB_CONNECTION_ERROR_INVALID_SETTINGS:
			text = "The connection settings could not be validated by the broker";
		break;

		case ERRINFO_CB_SESSION_ONLINE_VM_BOOT_TIMEOUT:
			text = "Timeout while the endpoint VM was being started by the broker";
		break;

		case ERRINFO_CB_SESSION_ONLINE_VM_SESSMON_FAILED:
			text = "Session monitoring error while the endpoint VM was being started by the broker";
		break;

		case ERRINFO_REMOTEAPPSNOTENABLED:
			text = "The server can only host Remote Applications";
		break;

		case ERRINFO_UPDATESESSIONKEYFAILED:
			text = "Update of session keys failed";
		break;

		case ERRINFO_DECRYPTFAILED:
			text = "Decryption or session key creation failed";
		break;

		case ERRINFO_ENCRYPTFAILED:
			text = "Encryption failed";
		break;


		default:
			if (reason > 0x1000 && reason < 0x7fff)
			{
				text = "Internal protocol error";
			}
			else
			{
				text = "Unknown reason";
			}
	}
	error("disconnect: %s.\n", text);
}
